#!/bin/bash
#

source ${PRODUCTS}/setup
echo ${PRODUCTS}
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
geniedir=${PRODUCTS}/genie/v3249/${flvr}-nova
sourcedir=${PRODUCTS}/genie/v3249/source

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# declare now so we can setup
mkdir -p ${geniedir}
if [ ! -d ${geniedir} ]
then
   echo "ERROR: failed to create ${geniedir}"
   exit 1
fi
   echo "Declaring genie v3249 for ${flvr}"
if [ ${OS} = "Darwin" ]
then
   ups declare genie v3249 -r genie/v3249 -2 -m genie.table -q nova
else 
   ups declare genie v3249 -r genie/v3249 -4 -m genie.table -q nova
fi

# setup genie
setup genie v3249 -q nova
gccver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccver} = "4.5" ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

if [ -z ${PYLIB} ]
then
   echo "ERROR: failed to setup pythia"
   exit 1
else
   echo "PYLIB: ${PYLIB}"
fi

if [ -z ${LIBXML2_INC} ]
then
   echo "ERROR: failed to setup libxml"
   exit 1
else
   echo "LIBXML2_INC: ${LIBXML2_INC}"
fi

cd ${geniedir}
tar xzf ${sourcedir}/genie-3249.tar.gz

set -x

cd ${GENIE}

./configure  --prefix=${geniedir} \
--enable-lhapdf \
--with-pythia6-lib=${PYLIB} \
--with-lhapdf-lib=${LHAPDF_FQ_DIR}/lib \
--with-lhapdf-inc=${LHAPDF_INC} \
--with-libxml2-inc=${LIBXML2_INC}/libxml2 \
--with-libxml2-lib=${LIBXML2_FQ_DIR}/lib \
--with-log4cpp-inc=${LOG4CPP_INC} \
--with-log4cpp-lib=${LOG4CPP_FQ_DIR}/lib


make
make install

set +x

if [ ! -d ${GENIE}/lib ]
then
   echo "ERROR: failed to create ${geniedir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
   echo "Finished building genie for flavor ${flvr}"
setup genie v3249 -q nova
echo "genie is installed at ${GENIE}"

exit 0
